# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLineWithNounChild(Model):
    """BillEntryBodyLineWithNounChild.

    :param noun: The body line's noun
    :type noun: str
    :param value: The body line's numeric value
    :type value: float
    :param type: The body line's observation type
    :type type: str
    :param unit: The body line's unit
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'noun': {'key': 'noun', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, noun=None, value=None, type=None, unit=None):
        super(BillEntryBodyLineWithNounChild, self).__init__()
        self.noun = noun
        self.value = value
        self.type = type
        self.unit = unit
