# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlacePropertyCreate(Model):
    """EnergyStarPlacePropertyCreate.

    :param property_id: The property identifier
    :type property_id: int
    :param effective_date: The effective date
    :type effective_date: datetime
    :param value: The value of the property
    :type value: str
    """

    _attribute_map = {
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, property_id=None, effective_date=None, value=None):
        super(EnergyStarPlacePropertyCreate, self).__init__()
        self.property_id = property_id
        self.effective_date = effective_date
        self.value = value
