# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicPercentageBillSplitResponse(Model):
    """Defines details for a dynamic percentage split of use, cost, or both based
    on the use or cost values of the meters in the destination meter group.

    :param destination_meter_group: Meter group to receive the results of the
     split bill.
    :type destination_meter_group: ~energycap.sdk.models.MeterGroupChild
    :param source_value_to_split: Value to distribute to the destination
     meters
     "use", "cost", or "useAndCost"
    :type source_value_to_split: str
    :param destination_share_value: Value to define how dynamic percentages
     are calculated.
     "use" or "cost"
    :type destination_share_value: str
    """

    _attribute_map = {
        'destination_meter_group': {'key': 'destinationMeterGroup', 'type': 'MeterGroupChild'},
        'source_value_to_split': {'key': 'sourceValueToSplit', 'type': 'str'},
        'destination_share_value': {'key': 'destinationShareValue', 'type': 'str'},
    }

    def __init__(self, destination_meter_group=None, source_value_to_split=None, destination_share_value=None):
        super(DynamicPercentageBillSplitResponse, self).__init__()
        self.destination_meter_group = destination_meter_group
        self.source_value_to_split = source_value_to_split
        self.destination_share_value = destination_share_value
