# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceEnergyStarPlaceTypeResponse(Model):
    """PlaceEnergyStarPlaceTypeResponse.

    :param energy_star_place_type_id: The energy star place type identifier
    :type energy_star_place_type_id: int
    :param place_id: The place identifier
    :type place_id: int
    :param place_type_code: The place type code
    :type place_type_code: str
    :param place_type_info: The place type info
    :type place_type_info: str
    :param energy_star_property_id: The place EnergyStar PlaceType Identifier
    :type energy_star_property_id: int
    :param primary_type: The primary type
    :type primary_type: bool
    :param energy_star_place_properties: An array of energy star place
     properties
    :type energy_star_place_properties:
     list[~energycap.sdk.models.EnergyStarPlacePropertyResponse]
    """

    _attribute_map = {
        'energy_star_place_type_id': {'key': 'energyStarPlaceTypeId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_type_code': {'key': 'placeTypeCode', 'type': 'str'},
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
        'energy_star_property_id': {'key': 'energyStarPropertyId', 'type': 'int'},
        'primary_type': {'key': 'primaryType', 'type': 'bool'},
        'energy_star_place_properties': {'key': 'energyStarPlaceProperties', 'type': '[EnergyStarPlacePropertyResponse]'},
    }

    def __init__(self, energy_star_place_type_id=None, place_id=None, place_type_code=None, place_type_info=None, energy_star_property_id=None, primary_type=None, energy_star_place_properties=None):
        super(PlaceEnergyStarPlaceTypeResponse, self).__init__()
        self.energy_star_place_type_id = energy_star_place_type_id
        self.place_id = place_id
        self.place_type_code = place_type_code
        self.place_type_info = place_type_info
        self.energy_star_property_id = energy_star_property_id
        self.primary_type = primary_type
        self.energy_star_place_properties = energy_star_place_properties
