# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectTypeCreate(Model):
    """EnergyProjectTypeCreate.

    :param energy_project_type_code: The energy project type code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type energy_project_type_code: str
    :param energy_project_type_info: The energy project type  info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type energy_project_type_info: str
    """

    _validation = {
        'energy_project_type_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'energy_project_type_info': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'energy_project_type_info': {'key': 'energyProjectTypeInfo', 'type': 'str'},
    }

    def __init__(self, energy_project_type_code, energy_project_type_info):
        super(EnergyProjectTypeCreate, self).__init__()
        self.energy_project_type_code = energy_project_type_code
        self.energy_project_type_info = energy_project_type_info
