# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelChild(Model):
    """ChannelChild.

    :param channel_id:
    :type channel_id: int
    :param channel_code:
    :type channel_code: str
    :param interval:
    :type interval: int
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, channel_id=None, channel_code=None, interval=None):
        super(ChannelChild, self).__init__()
        self.channel_id = channel_id
        self.channel_code = channel_code
        self.interval = interval
