# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeFormatResponse(Model):
    """TimeFormatResponse.

    :param display_name:
    :type display_name: str
    :param format_mask:
    :type format_mask: str
    """

    _attribute_map = {
        'display_name': {'key': 'displayName', 'type': 'str'},
        'format_mask': {'key': 'formatMask', 'type': 'str'},
    }

    def __init__(self, display_name=None, format_mask=None):
        super(TimeFormatResponse, self).__init__()
        self.display_name = display_name
        self.format_mask = format_mask
