# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponse(Model):
    """MeterDigestGHGYearlyResponse.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param equivalent_co2_emissions_unit: The native use unit of measure
    :type equivalent_co2_emissions_unit: ~energycap.sdk.models.UnitChild
    :param ghg_scope: Greenhouse gas scope
    :type ghg_scope:
     ~energycap.sdk.models.MeterDigestGHGYearlyResponseGHGScope
    :param ghg_types: List of greenhouse gas types with use by year
    :type ghg_types:
     list[~energycap.sdk.models.MeterDigestGHGYearlyResponseGHGType]
    :param updated: The date and time the data was retrieved
    :type updated: datetime
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'equivalent_co2_emissions_unit': {'key': 'equivalentCO2EmissionsUnit', 'type': 'UnitChild'},
        'ghg_scope': {'key': 'ghgScope', 'type': 'MeterDigestGHGYearlyResponseGHGScope'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[MeterDigestGHGYearlyResponseGHGType]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, equivalent_co2_emissions_unit=None, ghg_scope=None, ghg_types=None, updated=None):
        super(MeterDigestGHGYearlyResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.equivalent_co2_emissions_unit = equivalent_co2_emissions_unit
        self.ghg_scope = ghg_scope
        self.ghg_types = ghg_types
        self.updated = updated
