# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingDelete(Model):
    """ReadingDelete.

    :param channel_id: The identifier for the channel of the reading <span
     class='property-internal'>Required</span>
    :type channel_id: int
    :param time_begin: The begin date and time of the set of readings to be
     deleted.
     If provided, readings after but NOT including the provided begin date and
     time will be deleted.
    :type time_begin: datetime
    :param time_end: The end date and time of the set of readings to be
     deleted.
     If provided, readings up to and including the provided end date and time
     will be deleted.
    :type time_end: datetime
    """

    _validation = {
        'channel_id': {'required': True},
    }

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'time_begin': {'key': 'timeBegin', 'type': 'iso-8601'},
        'time_end': {'key': 'timeEnd', 'type': 'iso-8601'},
    }

    def __init__(self, channel_id, time_begin=None, time_end=None):
        super(ReadingDelete, self).__init__()
        self.channel_id = channel_id
        self.time_begin = time_begin
        self.time_end = time_end
