# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationChild(Model):
    """WeatherStationChild.

    :param station_id:
    :type station_id: int
    :param station_code:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 6 characters</span>
    :type station_code: str
    :param station_info:  <span class='property-internal'>Must be between 0
     and 64 characters</span>
    :type station_info: str
    :param city:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type city: str
    :param state:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type state: str
    :param country:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type country: str
    """

    _validation = {
        'station_code': {'required': True, 'max_length': 6, 'min_length': 0},
        'station_info': {'max_length': 64, 'min_length': 0},
        'city': {'max_length': 32, 'min_length': 0},
        'state': {'max_length': 32, 'min_length': 0},
        'country': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, station_code, station_id=None, station_info=None, city=None, state=None, country=None):
        super(WeatherStationChild, self).__init__()
        self.station_id = station_id
        self.station_code = station_code
        self.station_info = station_info
        self.city = city
        self.state = state
        self.country = country
