# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupChild(Model):
    """PlaceGroupChild.

    :param place_group_id: The place group identifier
    :type place_group_id: int
    :param place_group_code: The place group code
    :type place_group_code: str
    :param place_group_info: The place group info
    :type place_group_info: str
    :param auto_group: Indicates if this place group is an autogroup
    :type auto_group: bool
    :param user_defined_auto_group: Indicates if this place group is an user
     defined auto group
    :type user_defined_auto_group: bool
    """

    _attribute_map = {
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
    }

    def __init__(self, place_group_id=None, place_group_code=None, place_group_info=None, auto_group=None, user_defined_auto_group=None):
        super(PlaceGroupChild, self).__init__()
        self.place_group_id = place_group_id
        self.place_group_code = place_group_code
        self.place_group_info = place_group_info
        self.auto_group = auto_group
        self.user_defined_auto_group = user_defined_auto_group
