# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleRequest(Model):
    """SystemUserRoleRequest.

    :param system_user_role_name:  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type system_user_role_name: str
    :param description:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 1000 characters</span>
    :type description: str
    :param permissions:
    :type permissions: ~energycap.sdk.models.PermissionsRequest
    """

    _validation = {
        'system_user_role_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'description': {'required': True, 'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permissions': {'key': 'permissions', 'type': 'PermissionsRequest'},
    }

    def __init__(self, system_user_role_name, description, permissions=None):
        super(SystemUserRoleRequest, self).__init__()
        self.system_user_role_name = system_user_role_name
        self.description = description
        self.permissions = permissions
