# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseCostDeltaChild(Model):
    """BillingPeriodUseCostDeltaChild.

    :param billing_period: The billing period that the data represents.
     Will be the current billing period, the same year prior billing period,
     or the same period prior year billing period.
    :type billing_period: int
    :param use: The total common use for the specified billing period, and the
     change from this billing period to the current billing period.
     Will be null if there is no use (i.e. supplier meter) in the period.
    :type use: ~energycap.sdk.models.BillingPeriodUseUnitDeltaChild
    :param cost: The total cost for the specified billing period, and the
     change from this billing period to the current billing period.
    :type cost: ~energycap.sdk.models.BillingPeriodCostUnitDeltaChild
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'use': {'key': 'use', 'type': 'BillingPeriodUseUnitDeltaChild'},
        'cost': {'key': 'cost', 'type': 'BillingPeriodCostUnitDeltaChild'},
    }

    def __init__(self, billing_period=None, use=None, cost=None):
        super(BillingPeriodUseCostDeltaChild, self).__init__()
        self.billing_period = billing_period
        self.use = use
        self.cost = cost
