# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationResponse(Model):
    """WeatherStationResponse.

    :param station_id: ID of the weather station
    :type station_id: int
    :param station_code: Weather station code
    :type station_code: str
    :param station_info: Weather station info
    :type station_info: str
    :param base_station_code: Code of the base weather station
     Will be null if not linked
    :type base_station_code: str
    :param channel: The channel containing the weather station's mean daily
     temperature
    :type channel: ~energycap.sdk.models.ChannelChild
    """

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'base_station_code': {'key': 'baseStationCode', 'type': 'str'},
        'channel': {'key': 'channel', 'type': 'ChannelChild'},
    }

    def __init__(self, station_id=None, station_code=None, station_info=None, base_station_code=None, channel=None):
        super(WeatherStationResponse, self).__init__()
        self.station_id = station_id
        self.station_code = station_code
        self.station_info = station_info
        self.base_station_code = base_station_code
        self.channel = channel
