# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchEdit(Model):
    """BatchEdit.

    :param batch_code: The batch code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type batch_code: str
    :param note: Note/comment for batch <span class='property-internal'>Must
     be between 0 and 255 characters</span>
    :type note: str
    """

    _validation = {
        'batch_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_code': {'key': 'batchCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, batch_code, note=None):
        super(BatchEdit, self).__init__()
        self.batch_code = batch_code
        self.note = note
