# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseTargetComparison(Model):
    """PlaceDigestGHGYearlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param equivalent_co2_emissions: Equivalent CO2 emissions for the target
     year
    :type equivalent_co2_emissions: float
    :param equivalent_co2_emissions_ytd: Equivalent CO2 emissions for the
     target year up to the target period that corresponds to the current period
    :type equivalent_co2_emissions_ytd: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'equivalent_co2_emissions': {'key': 'equivalentCO2Emissions', 'type': 'float'},
        'equivalent_co2_emissions_ytd': {'key': 'equivalentCO2EmissionsYtd', 'type': 'float'},
    }

    def __init__(self, target_year=None, target_label=None, equivalent_co2_emissions=None, equivalent_co2_emissions_ytd=None):
        super(PlaceDigestGHGYearlyResponseTargetComparison, self).__init__()
        self.target_year = target_year
        self.target_label = target_label
        self.equivalent_co2_emissions = equivalent_co2_emissions
        self.equivalent_co2_emissions_ytd = equivalent_co2_emissions_ytd
