# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FileContentResult(Model):
    """FileContentResult.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param file_contents:
    :type file_contents: bytearray
    :ivar content_type:
    :vartype content_type: str
    :param file_download_name:
    :type file_download_name: str
    :param last_modified:
    :type last_modified: datetime
    :param entity_tag:
    :type entity_tag: ~energycap.sdk.models.EntityTagHeaderValue
    :param enable_range_processing:
    :type enable_range_processing: bool
    """

    _validation = {
        'content_type': {'readonly': True},
    }

    _attribute_map = {
        'file_contents': {'key': 'fileContents', 'type': 'bytearray'},
        'content_type': {'key': 'contentType', 'type': 'str'},
        'file_download_name': {'key': 'fileDownloadName', 'type': 'str'},
        'last_modified': {'key': 'lastModified', 'type': 'iso-8601'},
        'entity_tag': {'key': 'entityTag', 'type': 'EntityTagHeaderValue'},
        'enable_range_processing': {'key': 'enableRangeProcessing', 'type': 'bool'},
    }

    def __init__(self, file_contents=None, file_download_name=None, last_modified=None, entity_tag=None, enable_range_processing=None):
        super(FileContentResult, self).__init__()
        self.file_contents = file_contents
        self.content_type = None
        self.file_download_name = file_download_name
        self.last_modified = last_modified
        self.entity_tag = entity_tag
        self.enable_range_processing = enable_range_processing
