# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AucRangeRequest(Model):
    """AucRangeRequest.

    :param commodity_id: The unique identifier for the commodity
    :type commodity_id: int
    :param lower_limit_multiplier: When the current bill's average unit cost
     is LOWER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill <span
     class='property-internal'>Must be between 0.1 and 20.0</span>
    :type lower_limit_multiplier: float
    :param upper_limit_multiplier: When the current bill's average unit cost
     is HIGHER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill <span
     class='property-internal'>Must be between 0.1 and 20.0</span>
    :type upper_limit_multiplier: float
    """

    _validation = {
        'lower_limit_multiplier': {'maximum': 20, 'minimum': 0.1},
        'upper_limit_multiplier': {'maximum': 20, 'minimum': 0.1},
    }

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'lower_limit_multiplier': {'key': 'lowerLimitMultiplier', 'type': 'float'},
        'upper_limit_multiplier': {'key': 'upperLimitMultiplier', 'type': 'float'},
    }

    def __init__(self, commodity_id=None, lower_limit_multiplier=None, upper_limit_multiplier=None):
        super(AucRangeRequest, self).__init__()
        self.commodity_id = commodity_id
        self.lower_limit_multiplier = lower_limit_multiplier
        self.upper_limit_multiplier = upper_limit_multiplier
